import com.aspose.barcode.EncodeTypes;
import com.aspose.barcode.barcoderecognition.*;
import com.aspose.barcode.generation.BarcodeGenerator;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;

public class RecognitionExamples
{
    public static void main(String[] args) throws IOException
    {
        RecognitionExamples recognitionExamples = new RecognitionExamples();
        recognitionExamples.howToCustomerInformationInterpretingType1();
        recognitionExamples.howToCustomerInformationInterpretingType2();
        recognitionExamples.howToDetectEncodingEnabled();
        recognitionExamples.howToGetCodeBytes();
        recognitionExamples.howToMacroPdf417();
        recognitionExamples.howToReadFromFile();
        recognitionExamples.howToRecognitionCode11();
        recognitionExamples.howToRecognitionCode128();
        recognitionExamples.howToRecognitionCodeAllSupportedTypes();
        recognitionExamples.howToRecognitionCodeAllSupportedTypes2();
        recognitionExamples.howToRecognitionSetBarCodeImage();
        recognitionExamples.howToSetQualitySettings();
    }

    public final String subfolder = "resources/recognition/";

    public void howToReadFromFile()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String file_name = "code11.png";
        String full_path = this.subfolder + file_name;
        System.out.println(new File(full_path).exists());
        BarCodeReader reader = new BarCodeReader(full_path);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println(barCodeResult.getCodeText());
            System.out.println("\n");
            System.out.println(barCodeResult.getCodeTypeName());
        }

    }

    public void howToSetQualitySettings()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String file_name = "code11.png";
        String full_path = this.subfolder + file_name;
        System.out.println(new File(full_path).exists());
        BarCodeReader reader = new BarCodeReader(full_path);
        reader.setQualitySettings(QualitySettings.getHighPerformance());
        reader.getQualitySettings().setAllowMedianSmoothing(true);
        reader.getQualitySettings().setMedianSmoothingWindowSize(5);

        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println(barCodeResult.getCodeText());
            System.out.println("\n");
            System.out.println(barCodeResult.getCodeTypeName());
        }

    }


    public void howToGetCodeBytes() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        byte[] expectedCodeBytes = new byte[]{105, 99, 70, 1, 61, 0, 0, 2, 70, 10, 82, 20, 40, 0, 97, 106};
        String fileName = "example2.jpg";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)));
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            byte[] actualCodeBytes = barCodeResult.getCodeBytes();
            System.out.println("expected code bytes  : " + expectedCodeBytes.length);
            System.out.println("\n");
            System.out.println("actual code bytes  : " + actualCodeBytes.length);
        }
    }

    public void howToRecognitionCode128() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String fileName = "code128.jpg";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)), DecodeType.CODE_128);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("Code Text : " + barCodeResult.getCodeTypeName());
            System.out.println("\n");
            System.out.println("Code Type : " + barCodeResult.getCodeText());
        }

    }

    public void howToRecognitionCode11() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String fileName = "code11.png";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)), DecodeType.CODE_11);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("Code Text : " + barCodeResult.getCodeTypeName());
            System.out.println("\n");
            System.out.println("Code Type : " + barCodeResult.getCodeText());
        }

    }

    public void howToRecognitionCodeAllSupportedTypes() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String fileName = "example2.jpg";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)), DecodeType.ALL_SUPPORTED_TYPES);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("Code Text : " + barCodeResult.getCodeTypeName());
            System.out.println("\n");
            System.out.println("Code Type : " + barCodeResult.getCodeText());
        }

    }

    public void howToRecognitionCodeAllSupportedTypes2() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");

        String fileName = "example1.png";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)), DecodeType.ALL_SUPPORTED_TYPES);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("Code Text : " + barCodeResult.getCodeTypeName());
            System.out.println("\n");
            System.out.println("Code Type : " + barCodeResult.getCodeText());
        }

    }

    public void howToRecognitionSetBarCodeImage() throws IOException
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        String fileName = "code128.jpg";
        BarCodeReader reader = new BarCodeReader(ImageIO.read(new File(this.subfolder + fileName)), DecodeType.ALL_SUPPORTED_TYPES);
        reader.setBarCodeImage(this.subfolder + "code11.png");

        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("Code Text : " + barCodeResult.getCodeTypeName());
            System.out.println("\n");
            System.out.println("Code Type : " + barCodeResult.getCodeText());
        }

    }

    public void howToMacroPdf417()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        BarcodeGenerator gen = new BarcodeGenerator(EncodeTypes.MACRO_PDF_417, null);
        gen.setCodeText("codeSomecode");
        gen.getParameters().getBarcode().getPdf417().setPdf417MacroFileID(15900);
        gen.getParameters().getBarcode().getPdf417().setPdf417MacroSegmentID(2);
        gen.getParameters().getBarcode().getPdf417().setPdf417MacroSegmentsCount(3);
        BufferedImage image = gen.generateBarCodeImage();
        BarCodeReader reader = new BarCodeReader((image), DecodeType.MACRO_PDF_417);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("CodeText : " + barCodeResult.getCodeText());
        }

    }


    public void howToDetectEncodingEnabled()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        BarcodeGenerator gen = new BarcodeGenerator(EncodeTypes.QR, null);
        gen.setCodeText("Слово");
        gen.getParameters().getBarcode().getQR().setCodeTextEncoding(Charset.forName("Utf-8"));
        BufferedImage image = gen.generateBarCodeImage();

        BarCodeReader reader = new BarCodeReader(image, DecodeType.QR);
        reader.setDetectEncoding(true);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("CodeText : " + barCodeResult.getCodeText());
            System.out.println("\n");
            System.out.println("CodeType : " + barCodeResult.getCodeTypeName());
        }
    }

    public void howToCustomerInformationInterpretingType1()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        BarcodeGenerator generator = new BarcodeGenerator(EncodeTypes.AUSTRALIA_POST, null);
        generator.setCodeText("59123456781234567");
        generator.getParameters().getBarcode().getAustralianPost().setAustralianPostEncodingTable(CustomerInformationInterpretingType.N_TABLE);
        BufferedImage image = generator.generateBarCodeImage();
        BarCodeReader reader = new BarCodeReader((image), DecodeType.AUSTRALIA_POST);
        reader.setCustomerInformationInterpretingType(CustomerInformationInterpretingType.N_TABLE);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("CodeText : " + barCodeResult.getCodeText());
            System.out.println("\n");
            System.out.println("CodeType : " + barCodeResult.getCodeTypeName());
        }
    }

    public void howToCustomerInformationInterpretingType2()
    {
        System.out.println("\n---\nfunction '" + new Object()
        {
        }.getClass().getEnclosingMethod().getName() + "'\n");
        BarcodeGenerator generator = new BarcodeGenerator(EncodeTypes.AUSTRALIA_POST, null);
        generator.setCodeText("6212345678ABCdef123#");
        generator.getParameters().getBarcode().getAustralianPost().setAustralianPostEncodingTable(CustomerInformationInterpretingType.C_TABLE);
        BufferedImage image = generator.generateBarCodeImage();
        BarCodeReader reader = new BarCodeReader((image), DecodeType.AUSTRALIA_POST);
        reader.setCustomerInformationInterpretingType(CustomerInformationInterpretingType.C_TABLE);
        for (BarCodeResult barCodeResult : reader.readBarCodes())
        {
            System.out.println("CodeText : " + barCodeResult.getCodeText());
            System.out.println("\n");
            System.out.println("CodeType : " + barCodeResult.getCodeTypeName());
        }
    }
}